@@ -1,5 +1,5 @@
 package Net::Hadoop::Oozie;
-$Net::Hadoop::Oozie::VERSION = '0.108';
+$Net::Hadoop::Oozie::VERSION = '0.109';
 use 5.010;
 use strict;
 use warnings;
@@ -913,18 +913,18 @@ sub _jobs_iterator {
         $total_jobs += $jobs->{ $key } ? @{$jobs->{ $key }} : 0; # len overflow
         $offset     += $len;
 
-        my $rv = $cb->( $jobs );
+        my $ok = $cb->( $jobs );
 
-        next if ! $shortcircuit;
-
-        # If the option above is enabled, then the callback always need to
-        # return true to be able to continue.
-        #
-        if ( ! $rv ) {
-            if ( DEBUG ) {
-                printf STDERR "_jobs_iterator(short-circuit): callback returned false.\n";
+        if ( $shortcircuit ) {
+            # If the option above is enabled, then the callback always need to
+            # return true to be able to continue.
+            #
+            if ( ! $ok ) {
+                if ( DEBUG ) {
+                    printf STDERR "_jobs_iterator(short-circuit): callback returned false.\n";
+                }
+                $eof = 1;
             }
-            $eof = 1;
         }
 
     } while ! $eof && $offset < $total;
@@ -950,7 +950,7 @@ Net::Hadoop::Oozie
 
 =head1 VERSION
 
-version 0.108
+version 0.109
 
 =head1 SYNOPSIS
 
